#
# spec file for package gnome-sudoku
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gnome-sudoku
Version:        3.30.0
Release:        1.1
Summary:        Sudoku Game for GNOME
License:        GPL-3.0-or-later
Group:          Amusements/Games/Logic
URL:            https://wiki.gnome.org/Apps/Sudoku
Source:         http://download.gnome.org/sources/gnome-sudoku/3.30/%{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
# Needed for typelib() requires generator.
BuildRequires:  gobject-introspection
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.35.7.24
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0) >= 2.40.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.40.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.19.0
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(qqwing) >= 1.3.4

%description
Sudoku is a logic puzzle game, in which one must fill a 9 by 9 square
with the correct digits.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes -s %{buildroot}/%{_datadir}
%fdupes -s %{buildroot}/%{_libexecdir}

%files
%license COPYING
%doc NEWS
%doc %{_datadir}/help/C/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.sudoku.gschema.xml
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/metainfo/gnome-sudoku.appdata.xml
%{_mandir}/man6/%{name}.6%{?ext_man}
%{_bindir}/%{name}

%files lang -f %{name}.lang

%changelog
* Fri Sep  7 2018 antoine.belvire@opensuse.org
- Update to version 3.30.0:
  + Miscellaneous fixes to meson build system.
  + Miscellaneous fixes to user help.
  + Updated translations.
- Drop sudoku-fix-appdata-location.patch (fixed upstream).
- Remove lang package from recommended packages as it already
  supplements main package.
* Wed May 23 2018 luc14n0@linuxmail.org
- Update to version 3.29.2:
  + No visible changes for the user.
- Add:
  + meson BuildRequires and replace configure/make_build/make_\
    install macros with meson/meson_build/meson_install
    respectively, to follow upstream port to Meson build system.
  + sudoku-fix-appdata-location.patch.
- Drop update-desktop-files BuildRequires and suse_update_desktop_\
  file macro: they are no longer needed.
* Sun Mar 11 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Dec 22 2017 luc14n0@linuxmail.org
- Update to version 3.27.3:
  + Remove the OMF file.
  + Updated user docs.
  + Updated help.
  + Updated translations.
- Update Url to https://wiki.gnome.org/Apps/Sudoku: current
  Sudoku's web page.
- Adopt the use of %%make_build macro rather than raw make command,
  following the best practices.
- Drop %%glib2_gsettings_schema_requires macro: it's no longer
  required since RPM file triggers.
* Sat Sep  9 2017 dimstar@opensuse.org
- Update to version 3.26.0:
  + Updated translations.
* Sun Jul 16 2017 zaitor@opensuse.org
- Update to version 3.25.4:
  + Remove unnecessary css.
  + Updated translations.
- Drop obsolete post(un) handling, following macros removed:
  glib2_gsettings_schema_post(un), desktop_database_post(un) and
  icon_theme_cache_post(un).
- Run spec-cleaner, modernize spec.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Add flatpak manifest.
* Mon Mar 13 2017 dimstar@opensuse.org
- Update to version 3.23.92.1:
  + Revert "minor code update" that broke clearing cells.
- Changes from verison 3.23.92:
  + Bump required Vala version to ensure fix for bgo#779955.
  + Add OARS content rating metadata.
  + Minor code updates.
- Add vala BuildRequires: ensure to build from the vala sources
  instead fo the pre-shipped .c sources.
* Mon Nov  7 2016 zaitor@opensuse.org
- Update to version 3.22.2:
  + Use AX_REQUIRE_DEFINED in configure.ac.
  + Stop using intltool.
  + Update MSGCTXT and PACKAGE_GNU in Makevars.
  + Keep POTFILES in in alphabetical order.
  + Remove trailing whitespace.
  + Add translator comments to the .desktop file.
  + Updated translations.
- Drop intltool BuildRequires: No longer needed.
* Wed Sep 21 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + When pause is clicked, the game field should be hidden.
  + Updated translations.
* Fri Aug 19 2016 dimstar@opensuse.org
- Update to version 3.21.90:
  + Use namespace instead of class for SudokuGenerator.
  + Update appdata.
  + Simplify style-checker enabling code.
  + Fix style-checker with new libgnome-games-support.
  + Updated translations.
* Fri Aug 19 2016 zaitor@opensuse.org
- Update to version 3.21.4:
  + Drop using declarations.
  + Seed RNG for qqwing.
  + Switch to C++ 11.
  + Fix new warnings about static const variables.
  + Updated translations.
* Fri Aug 19 2016 zaitor@opensuse.org
- Update to version 3.21.3:
  + Always set header bar as the title bar.
  + Updated translations.
* Fri Aug 19 2016 zaitor@opensuse.org
- Update to version 3.20.5:
  + Properly hide game field during pause and show after resume.
* Wed Jul 13 2016 zaitor@opensuse.org
- Update to version 3.20.4:
  + Avoid accidental use of C++ 11.
* Wed Jul 13 2016 zaitor@opensuse.org
- Update to version 3.20.3:
  + Seed the RNG so we actually get different puzzles each run.
* Mon May 23 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Fix window size growing out of control with GTK+ 3.20.
* Sat May  7 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Updated translations.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Update license.
  + Use AM_DISTCHECK_CONFIGURE_FLAGS.
  + Bump up the license version on source files.
  + Update CSS for GTK+ 3.19.
  + Require GTK+ 3.19.
  + Update about dialog.
  + Add a missing tag to the AppData file.
  + Updated translations.
- Change license to GPL-3.0+, following upstreams relicensing.
* Mon Jan 18 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Update doap.
  + Update appdata.
  + Stop using deprecated gnome-common.
  + Add pre-commit and pre-applypatch hooks.
  + Updated translations.
* Tue Nov 24 2015 zaitor@opensuse.org
- Update to version 3.19.2:
  + Increase line width around 3x3.
* Fri Nov  6 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Updated translations.
* Sun Oct 11 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Mon Sep 14 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Reorder the buttons on the well done dialog.
  + Fix dragging the window after clicking the game view.
  + Updated translations.
* Sat Aug 15 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Hide number picker after selecting number with keyboard.
  + Fix build with Automake 1.15.
  + Updated translations.
* Mon May 25 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Replace high contrast icons with symbolic icon.
  + Add ability to enter puzzles manually.
  + Clear earmarks when a cell is filled.
  + Use sans font for all numbers when printing.
  + Allow cancelling print multiple puzzles.
  + Revert window title to say Difficulty rather than Puzzle.
  + Destroy GtkPopovers when not needed.
  + Do not save window size on exit if tiled.
  + Update and modernize user help index page.
  + Fix typos and grammar in user help.
  + Temporarily remove user help from app menu pending update.
  + Code cleanups.
  + Updated translations.
- Remove HighContrast %%icon_theme_cache_post(un) calls, as Symbolic
  icons have replaced them.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Install symbolic icon.
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Clear earmarks when a cell is filled.
  + Use sans for all numbers in printed sudokus.
  + Updated translations.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90.1:
  + Temporarily remove user help until it can be updated.
- Changes from version 3.15.90:
  + This release rolls back several changes that were present in
    3.15.2, most notably the addition of the timer, since we have
    not yet added scores and there is no point in having a timer
    without scores. The timer is expected to return in the 3.17
    development cycle. No other major changes.
* Sun Nov 30 2014 badshah400@gmail.com
- Update to version 3.15.2:
  + The highlighter can now be turned off with a preference.
  + XDG_CURRENT_DESKTOP may contain a list of desktops.
  + Updated translations.
- Changes from version 3.15.1:
  + Dependencies: GTK+ 3.15.0.
  + Add a timer counting up in the header bar.
  + When the game has been completed, the player may now choose
    between returning to the new game screen and quitting Sudoku,
    instead of returning to the new game screen or starting a new
    puzzle without changing the difficulty level.
  + Thread-safety fixes when printing multiple puzzles.
  + Fix crash when printing more than 16 puzzles on a computer
    with more than 16 CPUs.
  + Improve window titles.
  + Don't set the header bar as the title bar in Unity.
  + Only use a header bar on the print multiple puzzles dialog if
    the desktop environment requests it.
  + Widen the print multiple sudokus dialog.
  + Code cleanups.
  + Updated translations.
* Wed Nov 12 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Fix detection of Unity when XDG_CURRENT_DESKTOP contains a
    list.
  + Updated translations.
* Wed Oct 15 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Fix 100%% CPU usage after generating a puzzle.
  + Only use a header bar on the 'print multiple sudokus-dialog in
    environments that request it.
  + Don't set the main header bar as the title bar in Unity.
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Fixed multi-threading issues.
  + Updated translations.
* Tue Sep 16 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Fix the game in RTL locales.
  + Various code cleanups and improvements.
  + Various window layout and drawing improvements.
  + Add <ctrl>n and <ctrl>r accelerators.
  + Many miscellaneous bugfixes.
  + A few miscellaneous bugfixes.
  + Fix internationalization of game finished dialog.
  + Updated translations.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Started using QQwing as the puzzle generator.
  + Improved the board aesthetics.
  + Printing multiple puzzles is now multi-threaded.
  + Miscellaneous fixes and improvements.
  + Updated translations.
- Add gcc-c++ and pkgconfig(qqwing) BuildRequires: new dependency.
* Mon Jul 21 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Simplified the new game screen.
  + Improved the number picker design.
  + Lightly shade the current row, column and block.
  + Miscellaneous fixes and improvements.
  + Updated translations.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + Redesigned and rewritten.
- Update BuildRequires and Requires according the full rewrite in
  Vala instead of python.
* Mon Jun 30 2014 zaitor@opensuse.org
- Update to version 3.12.3:
  + Miscellaneous fixes.
  + Fix crash that was reported by Ubuntu's crash catcher over 5000
    times.
  + Some more stuff is translated now.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Updated translations.
* Mon Apr 14 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Updated translations.
* Mon Mar 24 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Fix some bugs with the user help.
  + Updated translations.
* Mon Mar 17 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Updated translations.
* Mon Feb 17 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + The colored grid no longer "dances" at the end of the game to
    reduce risk of epileptic seizures.
  + Fix deprecation warnings.
  + Updated translations.
- Add fdupes BuildRequires and run corresponding macro to remove
  duplicated files.
* Mon Dec 16 2013 dimstar@opensuse.org
- Update to version 3.11.3:
  + Fix VERSION and PREFIX.
  + Updated translations.
* Tue Nov 19 2013 dimstar@opensuse.org
- Update to version 3.11.2:
  + Port to Python 3.
  + Thicken 3x3 grids.
  + Exit on SIGINT.
  + Updated translations.
- Change python-gobject-cairo Requires to python3-gobject-cairo,
  following upstreams port to Python 3.
* Sun Nov 17 2013 dimstar@opensuse.org
- Update to version 3.11.1:
  + Appdata is now translatable.
  + Updated translations.
* Mon Nov 11 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + Quit when SIGINT is received instead of ignoring it.
* Sun Oct 13 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Updated translations.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Mon Sep 16 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Fix everything being initially hidden.
  + Fix a crash when clearing notes.
  + Slightly improve the look of the number pad.
  + Fix the high contrast icon.
  + Add an appdata file for GNOME Software.
  + Updated translations.
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Fix running uninstalled.
  + Fix NumberBox events configuration with latest pygobject.
  + Game no longer disappears when opening "print multiple sudokus"
    in fullscreen.
  + Reduce the width of the About dialog.
  + Don't use deprecated GObject.timeout_add_seconds.
  + Use /usr/bin/python instead of /usr/bin/env/python.
  + Fix some broken links in user help.
  + Updated translations.
- Drop gnome-sudoku-numberbox-events.patch: fixed upstream.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Updated translations.
* Thu Apr 11 2013 dimstar@opensuse.org
- Add gobject-introspection BuildRequires: add automatic typelib()
  requires to the package.
- Add python-gobject-cairo Requires: needed to start the game.
* Thu Apr 11 2013 dimstar@opensuse.org
- Add gnome-sudoku-numberbox-events.patch: Fix NumberBox envents
  configuration with latest pygobject.
* Wed Mar 27 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Enable maintainer mode by default.
  + Updated translations.
- Add icon_theme_post/postun calls for the new HighContrast icons.
* Tue Mar  5 2013 dimstar@opensuse.org
- Initial package, version 3.7.4. Split-off from gnome-games.
